/*
 * Copyright (C) 2011 Ion Pana, Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package org.freelords.army;

import java.util.Map;

import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

import org.freelords.army.jaxb.UnitStatsAdapter;

@XmlRootElement(name = "modifier")
/**
 * A modifier that changes stats of a unit.
 *
 * This class has a human-readable name (so a belt of giant strength gives a
 * modifier "giant strength"), and a set of stats that are augmented or
 * reduced. The modifier is always load from an xml file via jaxb.
 *
 * @see org.freelords.model.modifier.StatCalculator
 */
public class Modifier {

	@XmlElement(name = "name")
	private String name;
	
	@XmlElement(name = "stats")
	@XmlJavaTypeAdapter(UnitStatsAdapter.class)
	private Map<UnitStat, Integer> stats;
	
	public Modifier() {
	}
	
	/** Returns the name of the modifier. */
	public String getName() {
		return this.name;
	}
	
	/** Returns the modification of the given stat.
	  * @param stat The stat whose modification is requested.
	  * @return the value by which this stat is modified (can be negative).
	  */
	public int getStatValue(UnitStat stat) {
		return this.stats.get(stat).intValue();
	}

	@Override
	public boolean equals(Object obj) {
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final Modifier other = (Modifier) obj;
		if ((this.name == null) ? (other.name != null) : !this.name.equals(other.name)) {
			return false;
		}
		if (this.stats != other.stats && (this.stats == null || !this.stats.equals(other.stats))) {
			return false;
		}
		return true;
	}

	//Autogenerated by netbeans
	@Override
	public int hashCode() {
		int hash = 3;
		hash = 53 * hash + (this.name != null ? this.name.hashCode() : 0);
		hash = 53 * hash + (this.stats != null ? this.stats.hashCode() : 0);
		return hash;
	}
}
