/*
 * Copyright (C) 2011 Paul Statham
 *               2012 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.army.heroes;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/** Describes the equipment, i.e., the items that a hero carries on its body.
 *
 * Only the equipped items will be used in combat.
 */

@XmlRootElement(name = "equipment")
public class Equipment {
	
	@XmlElement(name = "armor")
	private Item armor;
	
	@XmlElement(name = "weapon")
	private Item weapon;
	
	@XmlElement(name = "misc")
	private Item misc;
	

	/**
	 * Equip an item into a slot
	 * 
	 * @throws IllegalStateException when slot is full
	 */
	public void equip(Item item) {
		ItemType itemType = item.getType();
		switch (itemType) {
			case ARMOR:
				throwExceptionOnFullSlot(armor);
				armor = item;
				break;
			case WEAPON:
				throwExceptionOnFullSlot(weapon);
				weapon = item;					
				break;
			case MISC:
				throwExceptionOnFullSlot(misc);
				misc = item;					
				break;
		}
	}

	/**
	 * Remove an item from a slot
	 * 
	 * @return Item from specified slot 
	 */
	public Item remove(ItemType itemType) {
		Item returnedItem = null;
		switch (itemType) {
			case ARMOR:
				returnedItem = armor;
				armor = null;
				break;
			case WEAPON:
				returnedItem = weapon;
				weapon = null;
				break;
			case MISC:
				returnedItem = misc;
				misc = null;
				break;
		}

		return returnedItem;
	}
	
	private void throwExceptionOnFullSlot(Item slot) {
		if (slot != null) {
			throw new IllegalStateException("This slot is full!");
		}
	}

}
