/*
 * Copyright (C) 2011 Paul Statham, Andrea Paternesi, Leonel Iturralde
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.army.heroes;

import java.util.Collections;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.freelords.army.Modifier;

@XmlRootElement(name = "item")
@XmlAccessorType(XmlAccessType.FIELD)
public class Item {

	@XmlElement(name = "name")
	private String name;

	@XmlElement(name = "usage-count")
	private Integer uses;

	@XmlElement(name = "armymodifier")
	private List<Modifier> armymodifiers;

	@XmlElement(name="unitmodifier")
	private List<Modifier> unitmodifiers;

	@XmlElement(name="type")
	private ItemType type;
	/**
	 * Returns item name
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Returns the item usage count
	 */
	public int getUses() {
		return this.uses;
	}

	/**
	 * Reduces item usage count by 1.
	 *
	 * @throws IllegalStateException if the usage count is already zero.
	 */
	public void use() {
		if(this.uses > 0) {
			this.uses -= 1;
		} else {
			throw new IllegalStateException("Usage count can't be less than 1");
		}
	}

	/** Returns whether the item is broken (i.e., has a usage count of zero). */
	public boolean isBroken() {
		if(this.uses == 0) {
			return true;
		} else {
			return false;
		}
	}

	/** Returns list of modifiers that affects the army.
	 * @return army modifiers
	 */
	public List<Modifier> getArmyModifiers() {
		return Collections.unmodifiableList(this.armymodifiers);
	}

	/** Returns list of modifiers that only affects a unit.
	 * @return Unit Modifiers
	 */
	public List<Modifier> getUnitModifiers() {
		return Collections.unmodifiableList(this.unitmodifiers);
	}

	/**
	 * Returns the Type of the item
	 * @return ItemType
	 */
	public ItemType getType() {
		return type;
	}

}
