/*
 * Copyright (C) 2011 Ion Pana, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.army.jaxb;

import java.util.ArrayList;
import java.util.EnumMap;
import java.util.List;
import java.util.Map;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.freelords.army.UnitStat;

/**
 * Needed by JAXB to convert from a simple type XmlUnitStats to a Map<UnitStat, Integer>.
 *
 */
public class UnitStatsAdapter extends XmlAdapter<XmlUnitStats, Map<UnitStat, Integer>> {

	/** static value assigned to all non-specified stats. */
	private static final int ZERO = 0;

	/** Convert the xml representation into a map of stats and values. */
	@Override
	public Map<UnitStat, Integer> unmarshal(XmlUnitStats xmlStats) throws Exception {
		Map<UnitStat, Integer> statMap = new EnumMap<UnitStat, Integer>(UnitStat.class);

		for (XmlUnitStatEntry entry : xmlStats.getList()) {
			statMap.put(entry.getStat(), entry.getValue());
		}

		for (UnitStat stat : UnitStat.values()) {
			if (statMap.get(stat) == null) {
				statMap.put(stat, ZERO);
			}
		}

		return statMap;
	}

	/** Convert a map of (stat,value) pairs to the xml representation. */
	@Override
	public XmlUnitStats marshal(Map<UnitStat, Integer> statMap) throws Exception {
		List<XmlUnitStatEntry> statEntryList = new ArrayList<XmlUnitStatEntry>();

		for (UnitStat stat : statMap.keySet()) {
			XmlUnitStatEntry entry = new XmlUnitStatEntry();
			entry.setStat(stat);
			entry.setValue(statMap.get(stat));
			statEntryList.add(entry);
		}

		XmlUnitStats xmlStats = new XmlUnitStats();
		xmlStats.setList(statEntryList);

		return xmlStats;
	}
}
