/*
 * Copyright (C) 2011 Ion Pana
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package org.freelords.log;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.logging.Formatter;
import java.util.logging.LogRecord;

public class LogFormatter extends Formatter {

	private static final String FORMAT = "dd/MM/yyyy hh:mm:ss";

	private static final DateFormat DF = new SimpleDateFormat(FORMAT);
	
	private static final String SEPARATOR = " ";
	
	@Override
	public synchronized String format(LogRecord record) {
		StringBuilder sb = new StringBuilder();
		
		//the date
		Date date = new Date();
		date.setTime(record.getMillis());
		sb.append(DF.format(date));
		
		//class, method
		/*
		 * TODO the issue is that because of the Log enum, the source class name
		 * and the source method name are mostly irrelevant.
		 * Discuss.
		if (record.getSourceClassName() != null) {
			sb.append(SEPARATOR).append(record.getSourceClassName());
		} else {
			sb.append(SEPARATOR).append(record.getLoggerName());
		}
		
		if (record.getSourceMethodName() != null) {
			sb.append(SEPARATOR).append(record.getSourceMethodName());
		}
		*/
		//the actual message
		sb.append(SEPARATOR);
		sb.append(record.getLevel().getLocalizedName());
		sb.append(": ");
		sb.append(formatMessage(record));
		sb.append("\n");
		//the thrown exception - this is 100% from SimpleLogFormatter
		if (record.getThrown() != null) {
		    try {
		        StringWriter sw = new StringWriter();
		        PrintWriter pw = new PrintWriter(sw);
		        record.getThrown().printStackTrace(pw);
		        pw.close();
			sb.append(sw.toString());
		    } catch (Exception ex) {
		    }
		}
		//and return
		return sb.toString();
	}

}
