/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *               2012 Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.main;

import com.esotericsoftware.kryonet.Client;

import java.io.IOException;
import java.io.OutputStream;
import org.freelords.network.client.FLNetworkClient;
import org.freelords.network.client.Session;
import org.freelords.network.client.FLNetworkClientListener;
import org.freelords.network.client.service.ClientChatService;
import org.freelords.network.client.service.UpdateClientInfoService;

/** Sets up a minimal client that can register itself and send/receive chat messages. */
public class FreelordsClientBuilder extends FreelordsNodeBuilder {

	private final OutputStream chatOutputStream;

	/**
	 * Creates and configures the Freelords Client.
	 * 
	 * @param chatOutputStream An output stream to print chat messages.
	 */
	public FreelordsClientBuilder(OutputStream chatOutputStream) {
		this.chatOutputStream = chatOutputStream;
	}

	/** Constructs a new client.
	 *
	 */
	public FLNetworkClient build() throws IOException {
		Client baseClient = new Client();
		Session session = new Session();

		FLNetworkClientListener listener = new FLNetworkClientListener();
		listener.registerService(new UpdateClientInfoService(session));
		listener.registerService(new ClientChatService(chatOutputStream,session));
		
		FLNetworkClient client = new FLNetworkClient(baseClient, session);		
		client.addReceivingListener(listener);
		registerClasses(client);
		client.initNetwork();

		return client;
	}
}
