/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.main;

import org.freelords.network.client.FLNetworkClient;
import org.freelords.network.command.ClientNetworkRegisterCommand;
import org.freelords.network.server.FLNetworkServer;

/** Startup function for the program.
  *
  * Note that right now this is intended as a basic demo program. It does not
  * do too much; most importantly, it does not do serious error handling.
  */

public class FreelordsMain {
	
	public static void main(String args[]) {
		if (args.length < 1) {
			System.out.println("Usage: Either \n" +
					"<progname> server <serverport> \nor\n" +
					"<progname> client <name> <server_ip> <server_port>");
			return;
		}

		try {
			if (args[0].equals("server")) {
				//System.setProperty("java.util.logging.config.file", "server.out");
				setupServer(args);

				// wait infinitely for the server to finish (or so).
				while (true) {
					Thread.sleep(1000);
				}
			} 
			else if (args[0].equals("client")) {
				//System.setProperty("java.util.logging.config.file", "client.out");
				FLNetworkClient client = setupClient(args);
				CommandReader reader = new CommandReader(System.in, System.out, client);
				reader.readCommands();
			}
			else {
				System.out.println("Illegal first parameter");
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/** Sets up and initializes a server. */
	public static FLNetworkServer setupServer(String args[]) throws Exception {
		int serverport = Integer.parseInt(args[1]);
		FreelordsServerBuilder serverBuilder = new FreelordsServerBuilder(serverport);

		FLNetworkServer freelordsServer = serverBuilder.build();
		freelordsServer.start();
		return freelordsServer;
	}

	/** Sets up and initializes a client and connects it to a server. */
	public static FLNetworkClient setupClient(String args[]) throws Exception {
		FreelordsClientBuilder clientBuilder = new FreelordsClientBuilder(System.out);
		FLNetworkClient freelordsClient = clientBuilder.build();
		freelordsClient.start();

		freelordsClient.connect(args[2], Integer.parseInt(args[3]));
		freelordsClient.sendCommand(new ClientNetworkRegisterCommand(args[1]));

		return freelordsClient;
	}
}
