/*
 * Copyright (C) 2011 Ulf Lorenz
 *               2012 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.main;

import java.util.HashMap;
import java.util.HashSet;

import org.freelords.network.command.ChatBroadcastCommand;
import org.freelords.network.command.ChatMulticastCommand;
import org.freelords.network.command.ClientNetworkRegisterCommand;
import org.freelords.network.common.FLNetworkNode;
import org.freelords.network.update.ChatUpdate;
import org.freelords.network.update.ClientListUpdate;
import org.freelords.network.update.ClientRegistrationUpdate;
import org.freelords.network.update.UpdateError;
import org.freelords.network.server.exception.ServiceException;


/** Generic setup of an FLNetworkNode.
  *
  * This class offers some functionality for registering the classes needed for
  * the network transfer in a specific order. kryonet uses an integer id for
  * enumerating the class type, and thus requires the server and the client to
  * call the registration commands in the same order. This is done here by having
  * both the client and the server builder refer to this superclass for the
  * registration commands.
  */
public class FreelordsNodeBuilder {

	protected void registerClasses(FLNetworkNode node) {
		node.registerClass(ClientNetworkRegisterCommand.class);
		node.registerClass(ChatBroadcastCommand.class);
		node.registerClass(ChatMulticastCommand.class);

		node.registerClass(ChatUpdate.class);
		node.registerClass(ClientListUpdate.class);
		node.registerClass(ClientRegistrationUpdate.class);
		node.registerClass(UpdateError.class);

		node.registerClass(ServiceException.class);

		node.registerClass(HashMap.class);
		node.registerClass(HashSet.class);
	}
}
