/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *               2012 Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.main;

import java.io.IOException;

import org.freelords.network.server.FLBaseServer;
import org.freelords.network.server.FLNetworkServer;
import org.freelords.network.server.FLNetworkServerListener;
import org.freelords.network.server.Updater;
import org.freelords.network.server.security.FLSecurityManager;
import org.freelords.network.server.service.ServerChatService;
import org.freelords.network.server.service.ServerClientRegisterService;


/** Sets up a server instance, registers all classes etc. */

public class FreelordsServerBuilder extends FreelordsNodeBuilder {

	private final Integer serverPort;

	/** Creates a new builder instance.
	 *
	 * @param serverPort    the port at which the created server should listen.
	 */
	public FreelordsServerBuilder(Integer serverPort) {
		this.serverPort = serverPort;
	}

	/** Creates and sets up a new server.
	 *
	 * @return a new server instance listening at the specified port.
	 * @throws IOException if anything with the setup goes wrong.
	 */
	public FLNetworkServer build() throws IOException {
		FLBaseServer baseServer = new FLBaseServer();

		FLSecurityManager securityManager = new FLSecurityManager();
		Updater updater = new Updater(baseServer);

		FLNetworkServerListener listener = new FLNetworkServerListener(securityManager, updater);
		listener.registerService(new ServerChatService());
		listener.registerService(new ServerClientRegisterService());

		FLNetworkServer freelordsServer = new FLNetworkServer(baseServer);
		freelordsServer.addReceivingListener(listener);
		freelordsServer.bindPort(serverPort);
		registerClasses(freelordsServer);
		freelordsServer.initNetwork();

		return freelordsServer;
	}
}
