/*
 * Copyright (C) 2011 Premkumar Bhaskal, Ulf Lorenz
 *               2012 Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.map;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;

import org.freelords.map.tile.MapTile;


/** An object located on a map.
  *
  * A MapEntity is every kind of object that can be found somewhere on the map.
  * In particular, armies, cities and villages fall into this category. Each map
  * tile stores all entities that can be found at the appropriate position.
  */

@XmlAccessorType(XmlAccessType.FIELD)
public class MapEntity {

	// made transient as it should not be serialized (map tiles store the
	// entities already, and we do not want recursion)
    // for this to work properly, XmlAccessorType should be set to XmlAccessType.FIELD
    // else we may get cyclic graph error while marshalling
	transient private MapTile mapTile;

	/** Returns the map tile that this entity belongs to. */
	public MapTile getMapTile() {
		return mapTile;
	}

	/** Sets the map tile which this entity belongs to. */
	public void setMapTile(MapTile mapTile) {
		this.mapTile = mapTile;
	}

	/** Helper function that returns the position where this entity is located. */
	public Position getPosition() {
		return mapTile.getPosition();
	}
	
}
