/*
 * Copyright (C) 2011 Leonel Iturralde, Ulf Lorenz, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.map.building.city;

import java.util.Collections;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.freelords.map.PlayerPropertyEntity;

/**
 * Represents a city on the map.
 * 
 * Gameplay-wise, a city belongs to a player, and provides income and
 * unit-building capabilities. Each city has a couple of villages attached,
 * which provide the actual income and most of the unit building, and which can
 * be blocked, thus lowering the city's capabilities.
 */

@XmlRootElement(name = "city")
@XmlAccessorType(XmlAccessType.FIELD)
public class City extends PlayerPropertyEntity {

	@XmlElement(name = "name")
	private String name;

	@XmlElement(name = "villages-owned")
	private List<String> villageIds;

	/**
	 * Getter of name
	 * 
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Setter of name
	 * @param name the name to set
	 * @throws IllegalStateException if name already set
	 */
	public void setName(String name) throws IllegalStateException {
		if (this.name == null) {
			this.name = name;
		} else {
			throw new IllegalStateException("This City already had a name");
		}
	}

	/**
	 * Returns a unmodifiableList of Strings that contains the ids of the
	 * villages owned by the City
	 * @return the villageIds
	 */
	public List<String> getListOfOwnedVillages() {
		return Collections.unmodifiableList(villageIds);
	}

	/**
	 * Setter of villageIds field
	 * @param villageIds the villageIds to set
	 * @throws IllegalStateException if Village Ids List is already set
	 */
	public void setListOfOwnedVillages(List<String> villageIds) {
		if (this.villageIds == null) {
			this.villageIds = villageIds;
		} else {
			throw new IllegalStateException("The list of village Ids is set");
		}
	}

}
