/*
 * Copyright (C) 2011 Paul Statham, Andrea Paternesi, Leonel Iturralde, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.map.building.village;

import java.util.UUID;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.freelords.map.PlayerPropertyEntity;

@XmlRootElement(name = "village")
@XmlAccessorType(XmlAccessType.FIELD)
public class Village extends PlayerPropertyEntity {
	@XmlElement(name = "id")
	private String id;

	@XmlElement(name = "siege-flag")
	private boolean underSiege;

	@XmlElement(name = "income")
	private Integer income;

	public Village() {
	}

	/**
	 * Getter of Id field
	 * @return Id
	 */
	public String getId() {
		return this.id;
	}

	public void setId() throws IllegalStateException {
		if (this.id == null) {
			this.id = UUID.randomUUID().toString();
		} else {
			throw new IllegalStateException("The Id is already set");
		}
	}

	/**
	 * Sets the siege flag boolean value
	 * @param underSiege - boolean value representing under siege status
	 */
	public void setUnderSiege(boolean underSiege) {
		this.underSiege = underSiege;
	}

	/** Return under siege status */
	public boolean isUnderSiege() {
		return this.underSiege;
	}

	/** Return the Village income value */
	public int getIncome() {
		return this.income;
	}

	/**
	 * Setter for the village income
	 * @param income - Integer value representing income of village
	 * @throws IllegalStateException if income already set
	 */
	public void setIncome(Integer income) {
		if (this.income == null) {
			this.income = income;
		} else {
			throw new IllegalStateException("This village already has an income!");
		}

	}

}
