/*
 * Copyright (C) 2011 Anton Kirillov, Andrea Paternesi, Ulf Lorenz, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.map.tile;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlRootElement;
import org.freelords.map.Position;
import org.freelords.map.tile.Access;
import org.freelords.map.MapEntity;

/**
 * Holds the data for a single tile on the map
 */
@XmlRootElement(name = "mapTile")
@XmlAccessorType(XmlAccessType.FIELD)
public class MapTile {

	@XmlElement(name = "name")
	private String name;
	@XmlElement(name = "position")
	private Position position;
	/**
	 * Number of movement points that are needed to cross the tile
	 */
	@XmlElement(name = "movementPoints")
	private int movementPoints;
	@XmlElement(name = "access")
	private Access access;

	@XmlElementRef
	private List<MapEntity> mapEntities = new ArrayList<MapEntity>();

	public MapTile() {
	}

	public MapTile(String name, Position position, int movementPoints, Access access) {
		this.name = name;
		this.position = position;
		this.movementPoints = movementPoints;
		this.access = access;
	}

	public String getName() {
		return name;
	}

	public Position getPosition() {
		return position;
	}

	public int getPointsNumber() {
		return movementPoints;
	}

	public Access getAccess() {
		return access;
	}

	public boolean canWalkOn() {
		return Access.WALKABLE.equals(access);
	}

	public List<MapEntity> getMapEntities() {
		return Collections.unmodifiableList(mapEntities);
	}

	/**
	 * adds the mapEntity to the mapEntities list
	 * 
	 * @param mapEntity
	 * @throws IllegalArgumentException
	 *             if the mapEntity to be added is null
	 */
	public void addEntity(MapEntity mapEntity) {
		if (mapEntity == null) {
			throw new IllegalArgumentException("Cannot add a null element to the maptile's position.");
		}
		mapEntities.add(mapEntity);
	}

	/**
	 * removes the mapEntity from the mapEntities list 
	 * @param mapEntity
	 * @throws IllegalStateException
	 *             if the mapEntity to be removed is not found in the list
	 */
	public void removeEntity(MapEntity mapEntity) {
		if (!mapEntities.remove(mapEntity)) {
			throw new IllegalStateException("Entity " + mapEntity + " not found on this map tile.");
		}
	}

}
