/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.client;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;
import java.util.UUID;


/** Keeps session information about the current game state.
 *
 * This object keeps all transient session data, such as information on
 * registered clients, game data etc.
 */

// TODO: How to synchronize the session object? I added synchronize statements
//       to the relevant functions, but I think this is not going to help catch
//       race conditions.

public class Session {

	private Map<UUID,String> clientMapping = new HashMap<UUID,String>();
	private UUID curClientId;

	/** Creates a new empty Session object. */
	public Session() {
	}

	/** Updates the internal list of clients.
	 *
	 * @param clients the new mapping from client id's to client names.
	 */
	public synchronized void updateClients(Map<UUID,String> newClients) {
		clientMapping = new HashMap<UUID,String>(newClients);
	}

	/** Returns a set of the id's of all registered clients. */
	public synchronized Set<UUID> listClientIds() {
		return Collections.unmodifiableSet(clientMapping.keySet());
	}

	/** Returns the name of a client with a specific id. */
	public synchronized String getClientName(UUID id) {
		return clientMapping.get(id);
	}

	/** Sets the id of the client that holds the session object. */
	public synchronized void setCurrentClientId(UUID id) {
		curClientId = id;
	}

	/** Returns the id of the client that holds this session object. */
	public synchronized UUID getCurrentClientId() {
		return curClientId;
	}

	public synchronized boolean isListClientsIdEmpty() {
		return clientMapping.isEmpty();
	}
}
