/*
 * Copyright (C) 2011 Ulf Lorenz, Leonel Iturralde
 *               2012 Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.client.service;


import java.io.OutputStream;

import java.io.PrintStream;
import org.freelords.log.Log;
import org.freelords.network.client.Session;
import org.freelords.network.update.ChatUpdate;
import org.freelords.network.update.Update;


/** Primitive chat service that prints incoming chat messages to the console.
 */

public class ClientChatService implements ClientService {

	private Session session;
	private OutputStream outputStream;

	/** Constructs the chat service.
	 *
	 * @param outputStream   the stream to which we print the chat messages.
	 * @param session        an object that holds the information on registered clients.
	 */
	public ClientChatService(OutputStream outputStream, Session session) {
		this.session = session;
		this.outputStream = outputStream;
	}

	/** {@inheritDocs} */
	@Override
	public void execute(Update update) throws Exception {
		ChatUpdate chatUpdate = (ChatUpdate) update;
		Log.CLIENT.info("Recieved message from: " + session.getClientName(chatUpdate.getSenderId()));

		((PrintStream)outputStream).println("[ " + session.getClientName(chatUpdate.getSenderId())
				+ " ]: " + chatUpdate.getMessage());
	}

	/** {@inheritDocs} */
	@Override
	public boolean accept(Update update) {
		return (update instanceof ChatUpdate);
	}

}
