/*
 * Copyright (C) 2011 Ulf Lorenz, Andrea Paternesi, Leonel Iturralde
 *               2012 Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.client.service;

import org.freelords.log.Log;
import org.freelords.network.client.Session;
import org.freelords.network.update.ClientListUpdate;
import org.freelords.network.update.ClientRegistrationUpdate;
import org.freelords.network.update.Update;

/** Interface for services that act on updates sent to the client.
 *
 * Classes that implement this interface can attach to the client listener, in
 * which case they are passed updates that the client receives.
 */
public class UpdateClientInfoService implements ClientService {

	private Session session;

	public UpdateClientInfoService(Session session) {
		if (session == null) {
			Log.CLIENT.debug("A session object was null.");
			throw new IllegalArgumentException("Session object required.");
		}
		if (!session.isListClientsIdEmpty()) {
			Log.CLIENT.debug("A session object was empty.");
			throw new IllegalArgumentException("Session object must be empty.");
		}

		this.session = session;
	}

	/**
	 * Executes an update.
	 */
	@Override
	public void execute(Update update) throws Exception {
		update.updateSession(session);
	}

	/**
	 * @param command an Update
	 * @return true if this ClientService can accept specific Update
	 */
	@Override
	public boolean accept(Update update) {
		return (update instanceof ClientListUpdate || update instanceof ClientRegistrationUpdate);
	}
}
