/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.command;

/** Send a chat message over the Network in a BroadCast mode.
 *
 * <p>
 * By setting up and sending an instance of this command, the client can send
 * to all other clients a chat message. When the server receives this command
 * it will broadcast the message to all clients in the game.
 * </p>
 */

public class ChatBroadcastCommand implements FLNetworkCommand {

	private String chatText;


	/** No-args constructor required by kryonet. */
	private ChatBroadcastCommand() {}

	/** Constructs the command with a given chat text. */
	public ChatBroadcastCommand(String chatText) throws IllegalArgumentException {
		if (chatText == null) {
			throw new IllegalArgumentException("The Chat Message cannot be null");
		}
		this.chatText = chatText;
	}

	/** Returns the text of the chat. */
	public String getChatText() {
		return chatText;
	}
}
