/*
 * Copyright (C) 2011 Andrea Paternesi, Pana Ion, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.command;

/** Sets a human-readable name for the client.
 *
 * <p>
 * By setting up and sending an instance of this command, the client can ask
 * the server to associate a certain human-readable name to itself (as opposed
 * to a simple numeric identifier). The name is interpreted as the name of the
 * respective player.
 * </p>
 */

public class ClientNetworkRegisterCommand implements FLNetworkCommand {
	private String clientName;

	/** No-args constructor required by kryonet */
	private ClientNetworkRegisterCommand() {}

	/** Constructs a command with a given client name. */
	public ClientNetworkRegisterCommand(String clientName) {
		this.clientName = clientName;
	}

	/** Returns the name that should be set. */
	public String getClientName() {
		return clientName;
	}
}
