/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.common;

import com.esotericsoftware.kryonet.Connection;
import java.util.UUID;

/** Represents a connection from the server to a given client.
 *
 * <p>
 * We augment the standard connections from kryonet by a couple of additional
 * parameters that the server should associate with a given client, namely a
 * unique identifier, the acess rights of this client, and possible a (player)
 * name.
 * </p>
 */

public class FLNetworkConnection extends Connection {

	private UUID clientId;
	private ClientRole role;
	private String clientName;

	/** Sets the access rights of the client. */
	public void setRole(ClientRole role) {
		this.role = role;
	}

	/** Returns the access rights of the client. */
	public ClientRole getRole() {
		return role;
	}

	/** Sets the unique identifier for the client. 
	 * The id is immutable after the first call.
	 *
	 * @throws IllegalStateException if the id has been set before.
	 */
	public void setClientId(UUID clientId) {
		if (this.clientId == null) {
			this.clientId = clientId;
		} else {
			throw new IllegalStateException("Client Id is already initialized!");
		}
	}

	/** Returns the unique identifier associated with the client. */
	public UUID getClientId() {
		return clientId;
	}

	/** Sets the player name for the client. Client name is immutable after first call.
	 * 
	 * @throws IllegalStateException when the clientName has been previousely initialized.*/
	public void setClientName(String clientName) {
		if (this.clientName == null) {
			this.clientName = clientName;
		} else {
			//client name should be immutable once set.
			throw new IllegalStateException("Client name is already initialized!");
		}
	}

	/** Returns the player name of this client. */
	public String getClientName() {
		return clientName;
	}
}
