/*
 * Copyright (C) 2011 Anton Kirillov
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.server;

import java.util.LinkedList;
import java.util.List;
import java.util.UUID;

import org.freelords.network.common.FLNetworkConnection;
import org.freelords.network.update.Update;

import com.esotericsoftware.kryonet.Connection;

public class Updater {

	private FLBaseServer server;

	public Updater(FLBaseServer server) {
		if (server == null) {
			throw new IllegalArgumentException("FLBaseServer is null");
		}
		this.server = server;
	}

	/**
	 * Broadcast update to all connected clients 
	 */
	public void broadcastUpdate(Update update) {
		if (update == null) {
			throw new IllegalArgumentException("Update is null");
		}
		for (Connection connection : server.getConnections()) {
			if (((FLNetworkConnection) connection).getClientId() != null) {				
				connection.sendTCP(update);
			}
		}
	}

	/**
	 * Send update to client with specified Id 
	 */
	public void sendUpdate(UUID clientId, Update update) {
		if (update == null || clientId == null) {
			throw new IllegalArgumentException("Argument is null");
		}

		for (Connection connection : server.getConnections()) {
			if (clientId.equals(((FLNetworkConnection) connection).getClientId())) {
				connection.sendTCP(update);
				return;
			}
		}
		throw new IllegalArgumentException("Connection with specified clientId does not exist");
	}

	/**
	 * @return List of FLNetworkConnection which have a client id set
	 */
	public List<FLNetworkConnection> listConnections() {
		List<FLNetworkConnection> result = new LinkedList<FLNetworkConnection>();
		for (Connection connection : server.getConnections()) {
			FLNetworkConnection con = (FLNetworkConnection) connection;
			if (con.getClientId() != null) {
				result.add(con);
			}
		}
		return result;
	}
}
