/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.server.security;

import org.freelords.network.command.ClientNetworkRegisterCommand;
import org.freelords.network.command.FLNetworkCommand;
import org.freelords.network.common.FLNetworkConnection;

/** Checks if incoming commands may be executed at all.
 *
 * If the SecurityManager refuses a command, it is discarded.
 */

public class FLSecurityManager {

	/** Check whether a given command should be executed or not.
	 *
	 * @param connection    the connection over which the command was sent.
	 * @param command       the command received by the server.
	 */
	public boolean checkRights(FLNetworkConnection connection, FLNetworkCommand command) {
		// For uninitialized connections, we only allow commands for setting up the connection.
		if (connection.getClientId() == null) {
			return (command instanceof ClientNetworkRegisterCommand);
		}
		return true;
	}
}
