/*
 * Copyright (C) 2011 Ion Pana, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package org.freelords.network.server.service;

import org.freelords.network.command.FLNetworkCommand;
import org.freelords.network.common.FLNetworkConnection;
import org.freelords.network.server.Updater;

/**
 * Implementing classes react on a {@link org.freelords.network.command.FLNetworkCommand}
 * instance by implementing the execute() method.
 *
 * The implementing classes can be selective about what commands they will
 * execute by implementing the accept() method.  In order for a Service to
 * function properly, it must be registered with a 
 * {@link org.freelords.network.server.FLNetworkServerListener}.
 */

public interface Service {

	/**
	 * Executes a command.
	 * @param command  the command that was received.
	 * @param connection  the connection to the client that sent the command.
	 * @param updater  object to send messages back to clients
	 */
	public void execute(FLNetworkCommand command, FLNetworkConnection connection, Updater updater) throws Exception;
	
	/**
	 * Determines if the service is able to execute this command or not.
	 * @param command  the command that was received.
	 * @return true  if this Service can execute the specified command. 
	 * 			false otherwise.
	 */
	public boolean accept(FLNetworkCommand command);
	
}
