/*
 * Copyright (C) 2011 Anton Kirillov, Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.update;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import org.freelords.network.client.Session;

/**
 * This implements the server response after that a chat command is sent from a client. 
 * The update is sent to the relevant clients and owns the chat message and the 
 * id of the sender client.
 */
public class ClientListUpdate implements Update {
	
	// Note: kryonet does not like UUID, that is why we must cast to string
	private final Map<String, String> clients = new HashMap<String, String>();

	/**
	 * Adds a client to the list of the clients playing or guesting the game.
	 * 
	 * @param clientId The id of the new client
	 * @param clientName The name of the new client
	 */
	public void addClient(UUID clientId, String clientName) {
		this.clients.put(clientId.toString(), clientName);
	}
	
	/**
	 * This would update the Session object
	 * 
	 * @param session The session to be updated with new data.
	 */
	@Override
	public void updateSession(Session session) {
		Map<UUID, String> transformedMap = new HashMap<UUID, String>();
		for (String key : clients.keySet()) {
			transformedMap.put(UUID.fromString(key), clients.get(key));
		}

		session.updateClients(transformedMap);
	}
}
