/*
 * Copyright (C) 2011 Premkumar Bhaskal, Ulf Lorenz
 *               2012 Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.player;

import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.freelords.army.Army;
import org.freelords.map.building.city.City;
import org.freelords.map.building.village.Village;

@XmlRootElement(name = "player")
@XmlAccessorType(XmlAccessType.FIELD)
public class Player {

	@XmlElement(name = "title")
	private String title;
	@XmlElement(name = "side")
	protected PlayerSide side;

	protected List<Army> armies;
	protected List<City> cities;
	protected List<Village> villages;

	/**
	 * @return title of the player
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * @return side({@link PlayerSide}) of the Player
	 */
	public PlayerSide getSide() {
		return side;
	}

	/**
	 * @return list of ({@link Army})
	 */
	public List<Army> getArmies() {
		return armies;
	}

	/**
	 * @return list of ({@link City})
	 */
	public List<City> getCities() {
		return cities;
	}

	/**
	 * @return list of ({@link Village})
	 */
	public List<Village> getVillages() {
		return villages;
	}

	/**
	 * @return name prefixed with the title
	 */
	public String prependTitle(String name) {
		return title + " " + name;
	}

	public void addCity(City city) {
		cities.add(city);
	}

	public void addVillage(Village village) {
		villages.add(village);
	}

	public void addArmy(Army army) {
		armies.add(army);
	}
}
