/*
 * Copyright (C) 2011 Anton Kirillov
 *               2012 Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.player;

import org.freelords.army.Army;
import org.freelords.map.MapEntity;
import org.freelords.map.PlayerPropertyEntity;
import org.freelords.map.ScenarioMap;
import org.freelords.map.building.city.City;
import org.freelords.map.building.village.Village;
import org.freelords.map.tile.MapTile;

/**
 * Helper class which purpose is to fill player object based on {@link #scenarioMap} 
 */
public class PlayerManager {
	
	private final ScenarioMap scenarioMap;

	public PlayerManager(ScenarioMap scenarioMap) {
		this.scenarioMap = scenarioMap;
	}
	
	/**
	 * Iterate over {@link #scenarioMap} to find out player properties.
	 * @param Player object will be filled with his own estate, based on player side.
	 */
	public void fillPlayer(Player p) {
		for (MapTile tile: scenarioMap.getTiles()) {
			for (MapEntity e: tile.getMapEntities()) {
				if (e instanceof PlayerPropertyEntity && ((PlayerPropertyEntity)e).getPlayer().equals(p.getSide())) {
					if (e instanceof City) {
						p.addCity((City) e);
					} else if (e instanceof Village) {
						p.addVillage((Village) e);
					} else if (e instanceof Army) {
						p.addArmy((Army) e);
					} else {
						throw new UnsupportedOperationException("Invalid PlayerPropertyEntity type");
					}
				}
			}
		}
	}
	
}
