/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound;

import java.util.concurrent.BlockingQueue;

import org.freelords.sound.command.SoundCommand;

/** A thread that executes all runnables sent to it via a queue.
 *
 * Besides the AudioManager, this is the other part of the audio system. All
 * requests lead to the manager putting Runnable instances into a queue, while
 * this class sits at the other end of the queue and executes whatever is to be
 * done. This has the effect of resolving some possible deadlock-mechanisms.
 */

public class AudioManagerExecutor extends Thread {

	private BlockingQueue<SoundCommand> queue;

	/** Initializes the executor.
	 *
	 * @param queue
	 *          a queue from which we read the requests whatever we are supposed to do.
	 */
	public AudioManagerExecutor(BlockingQueue<SoundCommand> queue) {
		this.queue = queue;
	}

	/** Polls objects from the queue and sleeps if nothing to do. */
	@Override
	public void run() {
		while (true) {
			try {
				Runnable runnable = queue.take();
				runnable.run();
			}
			catch (Exception e) {
				// what do we do if there is an exception?
				// We can maybe report it; since we run in a separate thread,
				// there is noone else to refer to.
				e.printStackTrace();
			}
		}
	}
}
