/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound;

/** A wrapper around a sound line that allows the usual things like playing,
 * pausing music etc. */

public interface AudioPlayer {
	/** Starts playback. */
	public void start();

	/** Stops playback.
	 *
	 * This also cleans up the sound data etc. After it has been stopped,
	 * playback cannot be resumed.
	 */
	public void stop();

	/** Silences the thread.
	 *
	 * @throws UnsupportedOperationException if for some reason the line cannot
	 * be muted.
	 */
	public void mute();

	/** Reverts the effect of muting.
	 *
	 * @throws UnsupportedOperationException if for some reason the line does
	 * not support muting.
	 */
	public void resume();

	/** Changes the volume of the player.
	 *
	 *  @param volume
	 *          the volume to set. Allowed values go from zero to 100 percent
	 *          and indicate the amplitude relative to maximum volume.
	 */
	public void setVolume(int volume);

	/** Register a listener that gets notified when the player finished playing. */
	public void addAudioListener(AudioListener listener);

	/** Unregisters a listener. */
	public void removeAudioListener(AudioListener listener);
}
