/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound;

import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.BlockingQueue;
import javax.sound.sampled.Mixer;

import org.freelords.sound.command.SoundCommand;

/** A helper class that does all the setup required to get an AudioManager running.  */

public class AudioSetup {

	public static AudioManager setupAudioManager(Mixer mixer) {
		// for all realistic purposes, a queue with 50 commands should be
		// sufficient.
		BlockingQueue<SoundCommand> queue = new ArrayBlockingQueue<SoundCommand>(50);

		// put an executor at the one end of the queue
		AudioManagerExecutor executor = new AudioManagerExecutor(queue);
		executor.start();

		// and an audio manager at the other end; this is the object that gets
		// returned.
		AudioManager manager = new AudioManager(mixer, queue);
		return manager;
	}
}
