/*
 * Copyright (C) 2011 Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound.jaxb;

import java.util.ArrayList;
import java.util.EnumMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.adapters.XmlAdapter;
import org.freelords.sound.SoundEvent;
import org.freelords.sound.SoundMapping;

/** An adapter that converts between the XML representation and the HashMap. */
public class XmlHashMapAdapter extends XmlAdapter<XmlHashMapType, Map<SoundEvent, List<SoundMapping>>> {

	@Override
	public XmlHashMapType marshal(Map<SoundEvent, List<SoundMapping>> map) throws Exception {
		XmlHashMapType mapType = new XmlHashMapType();
		XmlHashMapEntryType entryType;
		List<XmlHashMapEntryType> entryList = new ArrayList<XmlHashMapEntryType>();
				
		for (SoundEvent soundEvent : map.keySet()) {
			entryType = new XmlHashMapEntryType();
			entryType.setKey(soundEvent);
			entryType.setValue(map.get(soundEvent));
			entryList.add(entryType);
		}

		mapType.setEntry(entryList);
		return mapType;
	}

	@Override
	public Map<SoundEvent, List<SoundMapping>> unmarshal(XmlHashMapType list) throws Exception {
		Map<SoundEvent, List<SoundMapping>> returnMap = new EnumMap<SoundEvent, List<SoundMapping>>(SoundEvent.class);

		for (XmlHashMapEntryType entry : list.getEntry()) {
			if (entry.getValue() != null && !entry.getValue().isEmpty()) {
				returnMap.put(entry.getKey(), entry.getValue());
			}
		}

		return returnMap;
	}
}
