/*
 * Copyright (C) 2011 Pana Ion, Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.army;

import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.Test;

public class UnitTest {

	private static final String SOME_ID = "some-id";
	private static final String SOME_OTHER_ID = "some-other-id";
	private Unit unit;

	/** Load the unit from a predefined xml file. */
	@Before
	public void setUp() throws Exception {
		this.unit = UnitManagerHelper.createTestUnitManager().createUnit("unit");
	}

	/** Check that the movement points can be set and get properly. */
	@Test
	public void checkSettingOfMovementPoints() {
		int mp = this.unit.getMovementPoints();
		this.unit.setMovementPoints(mp + 1);

		assertEquals("Movement points were not set correctly.", mp + 1, this.unit.getMovementPoints());
	}

	//Army Id tests
	/** Check that the unit can be given an id. */
	@Test
	public void testUnitGetSetId() {
		unit = new Unit();
		unit.setId(SOME_ID);
		assertEquals("The returned id was wrong.", SOME_ID, unit.getId());
	}

	/**
	 * Make sure that the unit id can only be set once (in the unit manager)
	 * and cannot be modified afterwards.
	 */
	@Test(expected = IllegalStateException.class)
	public void testUnitIdIsImmutableAndSetThrowsExceptionOnSecondCall() {
		unit = new Unit();
		unit.setId(SOME_ID);
		unit.setId(SOME_OTHER_ID);
	}
}
