/*
 * Copyright (C) 2011 Paul Statham
 *               2012 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.army.heroes;

import static org.junit.Assert.*;

import java.io.File;

import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.junit.Before;
import org.junit.Test;

public class EquipmentTest {

	private File itemFile = new File(this.getClass().getResource("files/item.xml").getFile());
	private Item item;
	private Equipment testEquipment;
	
	@Before
	public void setUp() throws Exception {
		XmlManager itemManager = XmlTestHelper.createXmlManagerFor(Item.class);
		this.item = itemManager.unmarshall(this.itemFile);
		this.testEquipment = new Equipment();
	}
	
	/* Test equipping and removing an item from the equipment */
	@Test
	public void testEquipAndRemove() {
		testEquipment.equip(item);
		Item removedItem = testEquipment.remove(item.getType());		
		assertEquals("Items are not equal!", removedItem, item);
	}
	
	/* Test adding an item to an already filled slot */
	@Test(expected = IllegalStateException.class)
	public void testEquipThrowsExceptionWhenSlotIsFull() {
		testEquipment.equip(item);
		testEquipment.equip(item);
	}

}
