/*
 * Copyright (C) 2011 Paul Statham, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.army.heroes;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertFalse;
import static junit.framework.Assert.assertTrue;

import java.io.File;

import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.junit.Before;
import org.junit.Test;

public class ItemTest {

	private File itemFile = new File(this.getClass().getResource("files/item.xml").getFile());
	private Item item;

	@Before
	public void setUp() throws Exception {
		XmlManager manager = XmlTestHelper.createXmlManagerFor(Item.class);
		this.item = manager.unmarshall(this.itemFile);
	}
	
	/**
	 * Test reducing item usage count and
	 * isItemBroken() when count == 1
	 */
	@Test
	public void testReduceUseCount() {
		//Initialise current value of usage count
		int uses = item.getUses();
		//Reduce usage count by 1
		item.use();
		//Test usage count has reduced
		assertEquals("Usage count not reduced", uses - 1, item.getUses());
	}

	/** Test that an item is broken if the count goes below one. */
	@Test
	public void testItemCanGetBroken() {
		assertFalse("Item should be functioning", item.isBroken());
		breakItem(item);
		assertTrue("Item should be broken", item.isBroken());
	}

	/**
	 * Test item usage count can't be less than 0
	 * otherwise it throws an IllegalStateException
	 */
	@Test(expected = IllegalStateException.class)
	public void testUseCantBeLessThanOne() {
		breakItem(item);
		item.use();
	}	

	private void breakItem(Item item) {
		while (item.getUses() > 0) {
			item.use();
		}
	}
}
