/*
 * Copyright (C) 2011 Mladen Uzelac, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package org.freelords.map;

import java.util.Random;

import static org.junit.Assert.*;
import org.junit.Test;

public class PositionTest {
	
	@Test
	public void testEquals() {
		Position p1 = new Position(3,3);
		Position p2 = new Position(3,3);
		Position p3 = new Position(3,4);
		String s = "test";

		assertFalse("Point must not equal null instance.", p1.equals(null));
		assertFalse("Point must not equal wrong class.", p1.equals(s));
		assertFalse("Different points must not be equal.", p1.equals(p3));
		assertTrue("Identical points must be equal.", p1.equals(p2));
	}
	
	@Test
	public void testHashCode() {
		Random rng = new Random();

		// identical points have identical hash codes
		Position p1 = new Position(rng.nextInt(), rng.nextInt());
		Position p2 = new Position(p1.getX(), p1.getY());
		assertEquals("Identical points must have identical hash codes!", p1.hashCode(), p2.hashCode());
		
		for (int i = 0; i < 1000; i++) {
			p1 = new Position(rng.nextInt(1000), rng.nextInt(1000));
			p2 = new Position(rng.nextInt(1000), rng.nextInt(1000));
			if (p1.getX() == p2.getX() && p1.getY() == p2.getY()) {
				continue;
			}

			assertFalse("Different points must have different hash codes!", p1.hashCode() == p2.hashCode());
		}
	}
}
