/*
 * Copyright (C) 2011 Paul Statham, Andrea Paternesi, Leonel Iturralde, Ulf Lorenz, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.map.building.village;

import java.util.Set;
import java.util.HashSet;

import org.junit.Before;
import org.junit.Test;
import static junit.framework.Assert.*;

public class VillageTest {

	private Village village;
	private final int THRESHOLD = 100;

	@Before
	public void setUp() throws Exception {
		this.village = new Village();
	}

	/**
	 * Test village under siege flag getter/setter
	 */
	@Test
	public void testVillageUnderSiegeGetterSetter() {
		this.village.setUnderSiege(true);
		assertTrue("Under Siege getter not working",
				this.village.isUnderSiege());
	}

	@Test
	public void checkIfIDIsCorrectlySet() {
		village.setId();
		assertNotNull("The Village Id is not set correctly", village.getId());
	}

	/**
	 * Test village income getter and setter
	 */
	@Test
	public void testVillageIncomeGetterSetter() {
		int income = 20;
		this.village.setIncome(income);
		assertEquals("Income setter not working", income,
				this.village.getIncome());
	}

	/**
	 * Make sure that the village income can only be set once and cannot be
	 * modified afterwards.
	 */
	@Test(expected = IllegalStateException.class)
	public void testVillageIncomeIsImmutableAndSetThrowsExceptionOnSecondCall() {
		village.setIncome(10);
		village.setIncome(20);
	}

	@Test(expected = IllegalStateException.class)
	public void VillageIDIsImmutableAndSetThrowsExceptionOnSecondCall() {
		village.setId();
		village.setId();
	}

	@Test
	public void checkThatIdsAreNotRepeated() {
		Set<String> setWithIds = new HashSet<String>();

		for (int i = 0; i < THRESHOLD; i++) {
			Village village = new Village();
			village.setId();
			setWithIds.add(village.getId());
		}

		assertEquals(
				"The set size was different from expected : at least one village id was not unique.",
				THRESHOLD, setWithIds.size());
	}
}
