/*
 * Copyright (C) 2011 Premkumar Bhaskal, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.map.tile;

import static org.junit.Assert.*;

import org.freelords.map.MapEntity;
import org.freelords.map.building.village.Village;

import org.junit.Before;
import org.junit.Test;

public class MapTileTest {

	private MapTile mapTile;
	private MapEntity mapEntity;

	@Before
	public void setup() {
		mapTile = new MapTile();
		mapEntity = new Village();
	}

	@Test
	public void testAddEntity() {
		mapTile.addEntity(mapEntity);

		assertFalse("The MapEntity is not added to the MapTile", mapTile.getMapEntities().isEmpty());
	}

	@Test
	public void testRemoveEntity() {
		mapTile.addEntity(mapEntity);
		mapTile.removeEntity(mapEntity);

		assertTrue("The MapEntity is not removed from the MapTile",
				mapTile.getMapEntities().isEmpty());
	}

	@Test(expected = IllegalArgumentException.class)
	public void testAddEntityThrowsExceptionForNullEntity() {
		mapTile.addEntity(null);
	}

	@Test(expected = IllegalStateException.class)
	public void testRemoveEntityThrowsExceptionForNonExistentEntity() {
		mapTile.removeEntity(mapEntity);
	}

	@Test(expected = UnsupportedOperationException.class)
	public void testReturnedEntityListIsNotModifiable() {
		mapTile.addEntity(mapEntity);
		mapTile.getMapEntities().remove(mapEntity);
	}

}
