/*
 * Copyright (C) 2011  Andrea Paternesi, Ulf Lorenz, Anton Kirillov, Paul Statham
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.client;

import org.freelords.network.client.fake.FakeClientService;
import org.freelords.network.fake.FakeUpdate;
import org.freelords.network.update.UpdateError;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class FLNetworkClientListenerTest {

	private final FLNetworkClientListener listener = new FLNetworkClientListener();
	private final FakeClientService fakeService = new FakeClientService();
	private final FakeUpdate fakeUpdate = new FakeUpdate();
	private final UpdateError updateError = new UpdateError(new Exception("Update Error message!"));

	@Before
	public void SetUp() {
		listener.registerService(fakeService);
	}
	
	@Test
	/**
	 * Test sending update error to client listener
	 */
	// TODO: as soon as we have loggers, use a fake logger to check that the
	// client writes something out.
	public void testExecuteUpdateError() {
		listener.received(null, updateError);
	}

	/**
	 * Test that the client service was registered and performs valid updates
	 */
	@Test
	public void testExecuteSingleUpdate() {
		listener.received(null, fakeUpdate);
		Assert.assertEquals("Listener did not execute ClientService on Update", 1, fakeUpdate.getUpdateCount());
	}

	/**
	 * Test that an unregistered service does not perform an update
	 */
	@Test
	public void testUnregister() {
		listener.unregisterService(fakeService);
		listener.received(null, fakeUpdate);
		Assert.assertEquals("Service was unregistered, Update should not be changed", 0, fakeUpdate.getUpdateCount());
	}

	/**
	 * Test that all registered services execute update 
	 */
	@Test
	public void testNotification2() {
		FakeClientService fakeService2 = new FakeClientService();
		FakeClientService fakeService3 = new FakeClientService();

		listener.registerService(fakeService2);
		listener.registerService(fakeService3);

		listener.received(null, fakeUpdate);
		Assert.assertEquals("The number of Services updated was wrong.",3, fakeUpdate.getUpdateCount());
	}
}
