/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.client.service;

import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import org.freelords.network.client.Session;
import org.freelords.network.fake.FakeUpdate;
import org.freelords.network.update.ChatUpdate;

import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.Test;


public class ClientChatServiceTest {
	private ClientChatService service;
	private Session session;
	private ByteArrayOutputStream outStream = new ByteArrayOutputStream();
	private ChatUpdate update;
	
	@Before
	public void setup() {
		// set up a session object with some name
		session = new Session();
		Map<UUID,String> nameMap = new HashMap<UUID,String>();
		UUID clientId = UUID.randomUUID();
		nameMap.put(clientId, "SomeFavoriteName");
		session.updateClients(nameMap);
		
		// create a service
		service = new ClientChatService(new PrintStream(outStream), session);
		
		// generate a chat update to pass to the service for testing.
		update = new ChatUpdate("A chat message", clientId);
	}

	@Test
	public void serviceAcceptsOnlyChatUpdates() {
		assertTrue("Service must accept chat updates.", service.accept(update));
		assertFalse("Service must not accept other updates.", service.accept(new FakeUpdate()));
	}
	
	@Test
	public void servicePrintsChatUpdateOnReceivingStuff() throws Exception {
		service.execute(update);
		
		String output = outStream.toString();
		assertTrue("ChatMessage did not appear in output.", output.contains(update.getMessage()));
		assertTrue("Chat sender did not appear in output.", 
				output.contains(session.getClientName(update.getSenderId())));
	}
}
