/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.client.service;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import org.freelords.network.client.fake.FakeSession;
import org.freelords.network.fake.FakeUpdate;
import org.freelords.network.update.ClientListUpdate;
import org.freelords.network.update.ClientRegistrationUpdate;

import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.Test;

public class UpdateClientInfoServiceTest {

	private UpdateClientInfoService service;
	private FakeSession session = new FakeSession();
	private Map<UUID,String> clientMap;

	@Before
	public void setup() {
		service = new UpdateClientInfoService(session);

		clientMap = new HashMap<UUID, String>();
		clientMap.put(UUID.randomUUID(), "someName");
		clientMap.put(UUID.randomUUID(), "anotherName");
	}

	@Test(expected = IllegalArgumentException.class)
	public void serviceRequiresSessionObject() {
		service= new UpdateClientInfoService(null);
	}

	@Test(expected = IllegalArgumentException.class)
	public void serviceRequiresEmptySessionObject() {
		session.updateClients(clientMap);
		service= new UpdateClientInfoService(session);
	}

	@Test
	public void testUpdatesThatServiceAccepts() {
		assertTrue("Service must accept ClientListUpdates.", 
				service.accept(new ClientListUpdate()));
		assertTrue("Service must accept ClientRegistrationUpdates.", 
				service.accept(new ClientRegistrationUpdate(UUID.randomUUID())));
		assertFalse("Service must not accept other updates.",
				service.accept(new FakeUpdate()));
	}

	@Test
	public void testThatRegistrationUpdateUpdatesId() throws Exception {
		ClientRegistrationUpdate update = new ClientRegistrationUpdate(UUID.randomUUID());
		service.execute(update);

		assertTrue("Client Id was not updated.", session.clientIdSet);
	}

	@Test
	public void testThatRegistrationUpdateUpdatesClientList() throws Exception {
		ClientListUpdate update = new ClientListUpdate();
		for (UUID key : clientMap.keySet()) {
			update.addClient(key, clientMap.get(key));
		}

		service.execute(update);
		assertTrue("Client ids were not updated properly", session.mapClientsIdSet);
	}
}
