/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.server.security;

import java.util.UUID;

import org.freelords.network.command.ClientNetworkRegisterCommand;
import org.freelords.network.common.FLNetworkConnection;
import org.freelords.network.fake.FakeNetworkCommand;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;
import org.junit.Test;

public class FLSecurityManagerTest {

	private FLSecurityManager securityManager = new FLSecurityManager();
	private FLNetworkConnection connection = new FLNetworkConnection();
	private FakeNetworkCommand command = new FakeNetworkCommand();
   
	@Test
	public void securityManagerBlocksExecutionOfCommandsFromUnregisteredPlayers() {
		boolean returnvalue = securityManager.checkRights(connection,command);

		assertFalse("Command was incorrectly allowed.", returnvalue);
	}

	@Test
	public void securityManagerDoesNotBlockExecutionOfRegistrationCommandsFromUnregisteredPlayers() {
		ClientNetworkRegisterCommand registerCommand = new ClientNetworkRegisterCommand("");
		boolean returnvalue = securityManager.checkRights(connection, registerCommand);

		assertTrue("Command was incorrectly blocked.", returnvalue);
	}

	@Test
	public void securityManagerDoesNotBlockExecutionOfCommandsFromRegisteredPlayers() {
		connection.setClientId(UUID.randomUUID());
		boolean returnvalue = securityManager.checkRights(connection,command);

		assertTrue("Command was not executed.", returnvalue);
	}
}
