/*
 * Copyright (C) 2011 Andrea Paternesi, Ulf Lorenz
 *               2012 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.network.server.service.fake;

import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

import org.freelords.network.command.*;

/** Implementation of ChatMulticastCommand that supports null ids.
 *
 * The whole purpose of this class is to test the chat service for resilience when
 * a malicious user sends null ids. The default implementation of ChatMulticastCommand
 * already catches this case, so we have to undo this catching again.
 */

public class FakeChatMulticastCommand extends ChatMulticastCommand {

	private boolean containsNull;

	public FakeChatMulticastCommand(String chatText, Set<String> clientIds) throws IllegalArgumentException {
        super(chatText, clientIds);

		if (clientIds.contains(null)) {
			containsNull = true;
		}
    }

	@Override
	public Set<UUID> getClientIds() {
		Set<UUID> retval = super.getClientIds();
		if (containsNull) {
			retval = new HashSet<UUID>(retval);
			retval.add(null);
		}

		return retval;
	}
		
	@Override
	protected void checkForNullIds(Set<String> clientIds) throws IllegalArgumentException {		
	}
}
