/*
 * Copyright (C) 2011 Anton Kirillov
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.player;

import java.io.File;

import junit.framework.Assert;

import org.freelords.army.Army;
import org.freelords.map.ScenarioMap;
import org.freelords.map.building.city.City;
import org.freelords.map.building.village.Village;
import org.freelords.player.fake.FakePlayer;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.junit.Before;
import org.junit.Test;

public class PlayerManagerTest {
	
	private static final String BLUE_VILLAGE = "blueVillage";
	private static final String RED_CITY = "redCity";
	private final File file = new File(this.getClass().getResource("files/scenarioMap.xml").getFile());
	private ScenarioMap map; 

	@Before
	public void setUp() throws Exception {
		XmlManager xmlManager = XmlTestHelper.createXmlManagerFor(ScenarioMap.class, City.class, Village.class, Army.class);
		map = xmlManager.unmarshall(file);
	}
	
	/**
	 * Check that the player manager has put the properties of players correctly 
	 */
	@Test
	public void test() {
		PlayerManager pm = new PlayerManager(map);
		Player redPlayer = new FakePlayer(PlayerSide.RED);
		pm.fillPlayer(redPlayer);
		Assert.assertEquals(1, redPlayer.getArmies().size());
		Assert.assertEquals(1, redPlayer.getCities().size());
		Assert.assertEquals(0, redPlayer.getVillages().size());
		Assert.assertEquals(RED_CITY, redPlayer.getCities().get(0).getName());
		
		Player bluePlayer = new FakePlayer(PlayerSide.BLUE);
		pm.fillPlayer(bluePlayer);
		Assert.assertEquals(2, bluePlayer.getArmies().size());
		Assert.assertEquals(1, bluePlayer.getVillages().size());
		Assert.assertEquals(BLUE_VILLAGE, bluePlayer.getVillages().get(0).getId());
	}

}
