/*
 * Copyright (C) 2011 Ion Pana
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.reflection;

import java.lang.reflect.Field;

/**
 * Helper class for testing. It's main purpose is to call methods and fetch fields that are private
 * and that cannot be reached by a class' public methods.
 * The main motivation is testing for JAXB marshall/unmarshall of private fields.
 */
public class ReflectionHelper {

	/**
	 * Get a field value from an instance.
	 * 
	 * @param instance the instance
	 * @param fieldName the field name
	 * @return the field value
	 */
	@SuppressWarnings({ "unchecked", "rawtypes" })
	public static <T, M> T getFieldValue(M instance, String fieldName) {
		try {
			Class klazz = instance.getClass();
			Field field = klazz.getDeclaredField(fieldName);
			field.setAccessible(true);
			return (T) field.get(instance);
		} catch (Exception e) {
			throw new RuntimeException(e);
		}
	}
	
}
