/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound;

import java.util.concurrent.ArrayBlockingQueue;
import java.util.concurrent.BlockingQueue;

import org.freelords.sound.command.SoundCommand;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/** Tests the AudioManagerExecutor class.
 *
 * Since the executor only, well, executes runnables that you send to it, this
 * is exactly what we are going to test.
 */

public class AudioManagerExecutorTest {

	/** Manipulated by the runnables sent to the executor. */
	private int testInteger;

	private AudioManagerExecutor executor;
	private BlockingQueue<SoundCommand> queue;

	/** Sets up the executor */
	@Before
	public void setupExecutor() {
		queue = new ArrayBlockingQueue<SoundCommand>(20);
		executor = new AudioManagerExecutor(queue);
		executor.start();

		testInteger = 0;
	}


	/** Tests that the executor executes a runnable sent to it. */
	@Test
	public void testExecutorRunningProperly() throws Exception {
		queue.offer(new SoundCommand() {

			public void run() {
				testInteger = 1;
			}
		});

		// sleep a bit to offer the other thread the chance to execute the request.
		Thread.sleep(10);

		Assert.assertEquals("Executor failed to run command", 1, this.testInteger);
	}

	/** Test that multiple runnables are executed in the proper order. */
	@Test
	public void testExecutionInCorrectOrder() throws Exception {
		queue.offer(new SoundCommand() {

			public void run() {
				testInteger = 5;
			}
		});

		queue.offer(new SoundCommand() {

			public void run() {
				testInteger *= 2;
			}
		});

		Thread.sleep(10);

		Assert.assertEquals("Executor ran commands in wrong order", 10, this.testInteger);
	}
}
