/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;

import org.junit.Assert;
import org.junit.Test;

import org.freelords.sound.fake.FakeMixer;

/** Test for setting up the audio system.
 *
 * We let it set up an AudioManager including the executor backend, and look if
 * the result works.
 */

public class AudioSetupTest {

	@Test
	public void runSomeAudioManager() throws Exception {
		FakeMixer mixer = new FakeMixer(10);
		AudioManager manager = AudioSetup.setupAudioManager(mixer);

		File musicFile = new File(this.getClass().getResource("full/test/test1.ogg").getFile());
		InputStream soundStream = new BufferedInputStream(new FileInputStream(musicFile));

		manager.playSound(soundStream);

		// let some time pass, since the setup is done in a separate thread.
		Thread.sleep(10);

		Assert.assertTrue("Clip is not playing properly.", mixer.getClip(0).isRunning());
	}
}
