/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound.fake;

import java.util.ArrayList;
import java.util.List;
import javax.sound.sampled.Control;
import javax.sound.sampled.Line;
import javax.sound.sampled.LineListener;
import javax.sound.sampled.LineUnavailableException;
import javax.sound.sampled.Mixer;

/** Fakes a mixer with a limited number of lines of type FakeClip.
 *
 * The lines can be requested for testing purposes.
 */

public class FakeMixer implements Mixer {

	/** A list of clips that we can hand out. */
	private List<FakeClip> clipList = new ArrayList<FakeClip>();
	/** The index of the next clip to hand out. */
	private int nextClip = 0;


	/** Initialises the fake mixer with a settable number of clips. */
	public FakeMixer(int numLines) {
		for (int i = 0; i < numLines; i++) {
			clipList.add(new FakeClip());
		}
	}

	/** Initialises the fake mixer with some clips. */
	public FakeMixer(List<? extends FakeClip> clips) {
		for (FakeClip clip : clips) {
			clipList.add(clip);
		}
	}

	public FakeClip getClip(int index) {
		return clipList.get(index);
	}

	//---------------------------------------------------------------
	// The few functions that we implement from the Mixer interface
	@Override
	public Line getLine(Line.Info info) throws LineUnavailableException {
		if (nextClip >= clipList.size()) {
			throw new LineUnavailableException("Not enough clips here.");
		}

		return clipList.get(nextClip++);
	}


	//---------------------------------------------------------------
	// and all the other mixer functions
	@Override
	public int getMaxLines(Line.Info info) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Mixer.Info getMixerInfo() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line.Info[] getSourceLineInfo() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line.Info[] getSourceLineInfo(Line.Info info) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line[] getSourceLines() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line.Info[] getTargetLineInfo() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line.Info[] getTargetLineInfo(Line.Info info) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line[] getTargetLines() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public boolean isLineSupported(Line.Info info) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public boolean isSynchronizationSupported(Line[] lines, boolean sync) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public void synchronize(Line[] lines, boolean sync) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public void unsynchronize(Line[] lines) {
		throw new UnsupportedOperationException("not implemented");
	}


	//---------------------------------------------------------------
	// All sorts of stuff that needs to be implemented for a Line

	@Override
	public void addLineListener(LineListener listen) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public void close() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Control getControl(Control.Type type) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Control[] getControls() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public Line.Info getLineInfo() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public boolean isControlSupported(Control.Type type) {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public boolean isOpen() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public void open() {
		throw new UnsupportedOperationException("not implemented");
	}

	@Override
	public void removeLineListener(LineListener listen) {
		throw new UnsupportedOperationException("not implemented");
	}
}
