/*
 * Copyright (C) 2011 Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound.fake;

import javax.sound.sampled.BooleanControl;
import javax.sound.sampled.Control;

/** A custom implementation of {@ref javax.sound.sampled.Clip} used for testing.
 *
 * This class only extends the normal FakeClip by allowing a single control,
 * which "mutes" the sound stream.
 */


public class MuteableFakeClip extends FakeClip {

	public MuteControl muting;

	public MuteableFakeClip() {
		this(false);
	}

	/** initialise our control */
	public MuteableFakeClip(boolean block) {
		super(block);

		muting = new MuteControl();
	}

	/** Return the MuteControl if requested, otherwise throw an exception. */
	@Override
	public Control getControl(Control.Type control) {
		if (control == BooleanControl.Type.MUTE) {
			return muting;
		}

		throw new IllegalArgumentException("Invalid control requested");
	}

	/** Return that we support muting. */
	@Override
	public boolean isControlSupported(Control.Type control) {
		if (control == BooleanControl.Type.MUTE) {
			return true;
		}

		return false;
	}

	public static class MuteControl extends BooleanControl {
		private boolean muted;

		public MuteControl() {
			super(BooleanControl.Type.MUTE, false);
			muted = false;
		}

		@Override
		public void setValue(boolean value) {
			muted = value;
		}

		@Override
		public boolean getValue() {
			return muted;
		}
	}
}
