/*
 * Copyright (C) 2011 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.sound.fake;

import javax.sound.sampled.FloatControl;
import javax.sound.sampled.Control;

/** A custom implementation of {@ref javax.sound.sampled.Clip} used for testing.
 *
 * This class only extends the normal FakeClip by allowing a single control,
 * which changes the master gain of the line.
 */


public class VolumeFakeClip extends FakeClip {

	public VolumeControl volume;

	public VolumeFakeClip() {
		this(false);
	}

	/** initialise our control */
	public VolumeFakeClip(boolean block) {
		super(block);

		volume = new VolumeControl();
	}

	/** Return the MuteControl if requested, otherwise throw an exception. */
	@Override
	public Control getControl(Control.Type control) {
		if (control == FloatControl.Type.MASTER_GAIN) {
			return volume;
		}

		throw new IllegalArgumentException("Invalid control requested");
	}

	/** Return that we support muting. */
	@Override
	public boolean isControlSupported(Control.Type control) {
		if (control == FloatControl.Type.MASTER_GAIN) {
			return true;
		}

		return false;
	}

	public static class VolumeControl extends FloatControl {
		private float volume;

		public VolumeControl() {
			super(FloatControl.Type.MASTER_GAIN, -30f, 70f, 1f, 1, 0f, "dB");

			volume = 0;
		}

		@Override
		public void setValue(float value) {
			if (volume > getMaximum() || volume < getMinimum()) {
				throw new IllegalArgumentException("volume out of range");
			}

			volume = value;
		}

		@Override
		public float getValue() {
			return volume;
		}
	}
}
