/*
 * Copyright (C) 2011 Ulf Lorenz, Andrea Paternesi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package org.freelords.sound.full.test;

import java.io.File;
import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioInputStream;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.Clip;
import javax.sound.sampled.DataLine;
import javax.sound.sampled.Mixer;
import org.junit.Test;

/** Just initialise the Java audio system and check that it works.
 *
 * We were especially interested in whether Clip.start() blocks or not.
 *
 */
public class AudioTest {

	@Test
	public void testBlocking() throws Exception {
		// it is admittedly pretty pointless to include the whole test in a
		// try-block, because it defeats the common notion of the purpose of a
		// test.  However, this test:
		// a) is not really a test, but more a code snipplet about setting up audio
		// b) it depends on hardware, and sound hardware tends to fail somtimes
		//    for reasons outside of our reach.
		try {
			AudioFormat requestedFormat = new AudioFormat(AudioFormat.Encoding.PCM_SIGNED, 44100, 16, 2, 4, 44100, false);
			File infile = new File(this.getClass().getResource("test1.ogg").getFile());

			System.out.println(AudioSystem.getAudioFileFormat(infile));

			AudioInputStream audioIn = AudioSystem.getAudioInputStream(infile);
			audioIn = AudioSystem.getAudioInputStream(requestedFormat, audioIn);

			DataLine.Info info = new DataLine.Info(Clip.class, audioIn.getFormat());
			Mixer mix = AudioSystem.getMixer(AudioSystem.getMixerInfo()[0]);
			// seems to be not required
			// mix.open();

			System.out.println("Maximum lines: " + mix.getMaxLines(info));

			Clip myclip = (Clip) mix.getLine(info);
			myclip.open(audioIn);


			System.out.println("Set up audio stuff\nStarting playback...");

			myclip.start();
			System.out.println("Started audio stuff...");

			Thread.sleep(1000);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
