/*
 * Copyright (C) 2011 Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.army;

import static junit.framework.Assert.assertEquals;

import java.io.File;

import org.freelords.army.Unit;
import org.freelords.army.UnitStat;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XPathHelper;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.freelords.army.Army;
import org.freelords.map.tile.MapTile;

public class ArmyJaxbTest {

	private XmlManager xmlManager;
	// files for deserializing and serializing the Player instance
	private File inputFile = new File(this.getClass()
			.getResource("files/army.xml").getFile());
	private File outputFile = new File("army_out.xml");
	// needed for verifications
	private XPathHelper xPathHelper = new XPathHelper(this.inputFile);

	@Before
	public void setUp() throws Exception {
		this.xmlManager = XmlTestHelper.createXmlManagerFor(MapTile.class,
				Army.class);
	}

	/** Load the player from an xml file. */
	@Test
	public void testArmyIsReadFromAnXml() throws Exception {
		// first an MapTile is obtained and then the associated MapEntity is
		// obtained from the xml
		MapTile maptile = this.xmlManager.unmarshall(this.inputFile);
		Army army = (Army) maptile.getMapEntities().get(0);
		// setting the parent MapTile
		army.setMapTile(maptile);
		validateInstance(army, this.xPathHelper);
	}

	/** Write the player to an xml file. */
	@Test
	public void testArmyIsWrittenInAnXml() throws Exception {
		MapTile maptile = xmlManager.unmarshall(this.inputFile);
		XmlTestHelper.writeObjectToFile(maptile, this.xmlManager,
				this.outputFile);
		Army army = (Army) maptile.getMapEntities().get(0);
		// setting the parent MapTile
		army.setMapTile(maptile);

		// validate
		validateInstance(army, new XPathHelper(this.outputFile));
	}

	@After
	public void cleanUp() {
		this.outputFile.delete();
	}

	private void validateInstance(Army army, XPathHelper helper) {
		Unit unit = army.getUnits().get(0);

		assertEquals("The position is not set correctly",
				helper.evaluateXPathAsInteger("//mapTile/position/x/text()"),
				army.getPosition().getX());
		assertEquals("The position is not set correctly",
				helper.evaluateXPathAsInteger("//mapTile/position/y/text()"),
				army.getPosition().getY());

		assertEquals("The unit is not set correctly",
				helper.evaluateXPathAsString("//army/unit/id/text()"),
				unit.getId());
		assertEquals(
				"The unit is not set correctly",
				helper.evaluateXPathAsInteger("//army/unit/movementPoints/text()"),
				unit.getMovementPoints());
		assertEquals("The unit is not set correctly",
				helper.evaluateXPathAsString("//army/unit/type/text()"),
				unit.getType());
		assertEquals(
				"The unit is not set correctly",
				helper.evaluateXPathAsInteger("//army/unit/stat-calculator/stats/entry[@stat='MAXIMUM_MOVE_POINTS']/@value"),
				unit.getUnitStat(UnitStat.MAXIMUM_MOVE_POINTS));
		assertEquals(
				"The unit is not set correctly",
				helper.evaluateXPathAsInteger("//army/unit/stat-calculator/stats/entry[@stat='UPKEEP']/@value"),
				unit.getUnitStat(UnitStat.UPKEEP));
		assertEquals(
				"The unit is not set correctly",
				helper.evaluateXPathAsString("//army/player"),
				army.getPlayer().toString());
	}

}
