/*
 * Copyright (C) 2011 Ion Pana, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.army;

import java.io.File;

import org.freelords.army.Modifier;
import org.freelords.army.UnitStat;
import org.freelords.xmlmanager.utils.XPathHelper;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;

import static junit.framework.Assert.*;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class ModifierJaxbTest {

	private XmlManager xmlManager;
	private File modifierFile = new File(this.getClass().getResource("files/modifier.xml").getFile());
	private File badModifierFile = new File(this.getClass().getResource("files/incomplete_modifier.xml").getFile());	
	private File outputFile = new File("modifier_output.xml");
	private Modifier modifier;

	@Before
	public void setUp() throws Exception {
		xmlManager = XmlTestHelper.createXmlManagerFor(Modifier.class);
		modifier = xmlManager.unmarshall(modifierFile);
	}

	@After
	public void cleanup() {
		outputFile.delete();
	}

	@Test
	public void testMissingStatsAreDefaultedToZero() throws Exception {
		modifier = xmlManager.unmarshall(this.badModifierFile);

		for (UnitStat stat : UnitStat.values()) {
			if (stat == UnitStat.MAXIMUM_MOVE_POINTS) {
				assertNotSame("Modifier should not have been zeroed.",
						0, modifier.getStatValue(UnitStat.MAXIMUM_MOVE_POINTS));
			} 
			else {
				assertEquals("Modifier was not set to zero.", 0, modifier.getStatValue(stat));
			}
		}
	}

	@Test
	public void testModifierIsLoadedFromXml() {
		assertNotNull("The modifier was null.", modifier);
		validateModifier(modifier, new XPathHelper(modifierFile));
	}

	@Test
	public void testModifierIsWrittenToXml() throws Exception {
		XmlTestHelper.writeObjectToFile(modifier, xmlManager, outputFile);
		validateModifier(modifier, new XPathHelper(outputFile));
	}

	private void validateModifier(Modifier modifier, XPathHelper helper) {
		assertEquals("The modifier name was wrong.", 
				helper.evaluateXPathAsString("//name/text()"),modifier.getName());
		assertEquals("The modifier MAXIMUM_MOVE_POINTS stat was wrong.", 
				helper.evaluateXPathAsInteger("//entry[@stat='MAXIMUM_MOVE_POINTS']/@value"), 
				modifier.getStatValue(UnitStat.MAXIMUM_MOVE_POINTS));
		assertEquals("The modifier UPKEEP stat was wrong.", 
				helper.evaluateXPathAsInteger("//entry[@stat='UPKEEP']/@value"),
				modifier.getStatValue(UnitStat.UPKEEP));
	}
}
