/*
 * Copyright (C) 2011 Ion Pana, Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

package org.freelords.xmlmanager.jaxb.army;

import java.util.Collections;
import java.util.EnumMap;
import java.util.Map;

import org.freelords.army.UnitStat;
import org.freelords.army.jaxb.UnitStatsAdapter;
import org.freelords.army.jaxb.XmlUnitStatEntry;
import org.freelords.army.jaxb.XmlUnitStats;

import static junit.framework.Assert.*;
import org.junit.Before;
import org.junit.Test;

public class UnitStatsAdapterTest {

	private UnitStatsAdapter adapter;
	private EnumMap<UnitStat, Integer> statMap;
	
	@Before
	public void setUp() {
		adapter = new UnitStatsAdapter();

		// initialize the list of stats
		statMap = new EnumMap<UnitStat, Integer>(UnitStat.class);
		for (UnitStat stat : UnitStat.values()) {
			statMap.put(stat, 0);
		}
		statMap.put(UnitStat.MAXIMUM_MOVE_POINTS, 5);
	}

	@Test
	public void testBasicMarshalAndUnmarshal() throws Exception {
		// first marshal a list of stats
		XmlUnitStats xmlstats = adapter.marshal(statMap);

		for (XmlUnitStatEntry entry : xmlstats.getList()) {
			assertEquals("Stats were not properly marshaled.",
					statMap.get(entry.getStat()).intValue(), entry.getValue());
		}

		// then unmarshal it again
		Map<UnitStat, Integer> otherMap = adapter.unmarshal(xmlstats);
		for (UnitStat stat : UnitStat.values()) {
			assertEquals("Stats were not properly unmarshaled again.",
					statMap.get(stat), otherMap.get(stat));
		}
	}

	@Test
	public void testZeroingOfUnassignedStats() throws Exception {
		// construct the xml representation by hand
		XmlUnitStatEntry entry = new XmlUnitStatEntry();
		entry.setStat(UnitStat.MAXIMUM_MOVE_POINTS);
		entry.setValue(5);

		XmlUnitStats xmlstats = new XmlUnitStats();
		xmlstats.setList(Collections.singletonList(entry));

		// and unmarshal it.
		Map<UnitStat, Integer> statMap = adapter.unmarshal(xmlstats);

		for (UnitStat stat : UnitStat.values()) {
			if (stat != UnitStat.MAXIMUM_MOVE_POINTS) {
				assertNotNull("Missing stats were not filled.", statMap.get(stat));
				assertEquals("Missing stats were not zeroed.", 0, statMap.get(stat).intValue());
			}
		}
	}
}
