/*
 * Copyright (C) 2012 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.army.heroes;

import java.io.File;

import org.freelords.army.heroes.Equipment;
import org.freelords.army.heroes.Item;
import org.freelords.army.heroes.ItemType;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.freelords.xmlmanager.utils.XPathHelper;

import static junit.framework.Assert.*;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class EquipmentJaxbTest {

	private XmlManager xmlManager;
	private File equipmentFile = new File(this.getClass().getResource("files/equipment.xml").getFile());
	private File outputFile = new File("equipment_output.xml");
	private Equipment equipment;

	@Before
	public void setUp() throws Exception {
		xmlManager = XmlTestHelper.createXmlManagerFor(Equipment.class);
		equipment = xmlManager.unmarshall(equipmentFile);
	}

	@After
	public void cleanup() {
		outputFile.delete();
	}

	@Test
	public void testEquipmentIsLoadedFromXml() {
		assertNotNull("The equipment was null.", equipment);
		validateEquipment(equipment, new XPathHelper(equipmentFile));
	}

	@Test
	public void testEquipmentIsWrittenToXml() throws Exception {
		XmlTestHelper.writeObjectToFile(equipment, xmlManager, outputFile);
		validateEquipment(equipment, new XPathHelper(outputFile));
	}

	private void validateEquipment(Equipment holdings, XPathHelper helper) {
		assertEquals("The weapon name was wrong.", 
				helper.evaluateXPathAsString("//weapon/name/text()"), equipment.remove(ItemType.WEAPON).getName());
		assertEquals("The armor name was wrong.", 
				helper.evaluateXPathAsString("//armor/name/text()"), equipment.remove(ItemType.ARMOR).getName());
		assertEquals("The misc. name was wrong.", 
				helper.evaluateXPathAsString("//misc/name/text()"), equipment.remove(ItemType.MISC).getName());
	}
}
