/*
 * Copyright (C) 2011 Paul Statham
 *               2012 Ulf Lorenz
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.army.heroes;

import java.io.File;

import org.freelords.army.heroes.Hero;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.freelords.xmlmanager.utils.XPathHelper;

import static org.junit.Assert.*;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class HeroJaxbTest {
	
	private XmlManager xmlManager;
	private File heroFile = new File(this.getClass().getResource("files/hero.xml").getFile());
	private File outputFile = new File("hero_output.xml");
	private Hero hero;
	
	@Before
	public void setUp() throws Exception {
		xmlManager = XmlTestHelper.createXmlManagerFor(Hero.class);
		this.hero = xmlManager.unmarshall(this.heroFile);
	}
	
	@After
	public void cleanup() {
		outputFile.delete();
	}

	@Test
	public void testHeroIsLoadedFromXml() {
		assertNotNull("The hero was null", hero);
		validateHero(hero, new XPathHelper(heroFile));
	}

	@Test
	public void testHeroIsWrittenToXml() throws Exception {
		XmlTestHelper.writeObjectToFile(hero, xmlManager, outputFile);
		validateHero(hero, new XPathHelper(outputFile));
	}

	/* Test getting hero name */
	private void validateHero(Hero hero, XPathHelper helper) {
		assertEquals("Hero name was wrong!", 
				helper.evaluateXPathAsString("//name/text()"), hero.getName());
	}
}
