package org.freelords.xmlmanager.jaxb.army.heroes;

import static junit.framework.Assert.assertEquals;

import java.io.File;

import org.freelords.army.heroes.Item;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XPathHelper;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.junit.Before;
import org.junit.Test;

public class ItemTest {

	private File itemFile = new File(this.getClass().getResource("files/item.xml").getFile());
	private Item item;

	@Before
	public void setUp() throws Exception {
		XmlManager manager = XmlTestHelper.createXmlManagerFor(Item.class);
		this.item = manager.unmarshall(this.itemFile);
	}

	/**
	 * Test item name can be retrieved
	 */
	@Test
	public void testGetItemName() {
		XPathHelper helper = new XPathHelper(itemFile);
		assertEquals("Item name incorrectly retrieved", helper.evaluateXPathAsString("//name/text()"),item.getName());
	}

	/**
	 * Test item usage count can be retrieved
	 */
	@Test
	public void testGetNumberOfUses() {
		XPathHelper helper = new XPathHelper(itemFile);
		assertEquals("Item usage number incorrect", helper.evaluateXPathAsString("//usage-count/text()"),String.valueOf(item.getUses()));
	}

	/**
	 * Test army modifier list can be retrieved
	 */
	@Test
	public void testGetArmyModifierList() {
		XPathHelper helper = new XPathHelper(itemFile);
		assertEquals("Modifier list incorrectly retrieved!", helper.evaluateXPathAsString("//armymodifier/name/text()"), item.getArmyModifiers().get(0).getName());
	}

	/**
	 * Test unit modifier list can be retrieved
	 */
	@Test
	public void testGetUnitModifierList() {
		XPathHelper helper = new XPathHelper(itemFile);
		assertEquals("Modifier list incorrectly retrieved!", helper.evaluateXPathAsString("//unitmodifier/name/text()"), item.getUnitModifiers().get(0).getName());
	}
	
	@Test
	public void testGetItemType(){
		XPathHelper helper = new XPathHelper(itemFile);
		assertEquals("Item name incorrectly retrieved",helper.evaluateXPathAsString("//type/text()"),item.getType().toString());
	}	
}
