/*
 * Copyright (C) 2011 Leonel Iturralde, Ulf Lorenz, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.map.building.city;

import java.io.File;

import org.freelords.map.building.city.City;
import org.freelords.map.tile.MapTile;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.freelords.xmlmanager.utils.XPathHelper;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import static junit.framework.Assert.assertEquals;

public class CityJaxbTest {

	private XmlManager manager;
	private File inputFile = new File(this.getClass()
			.getResource("files/city.xml").getFile());
	private File outputFile = new File("test_city.xml");

	@Before
	public void setUp() throws Exception {
		manager = XmlTestHelper.createXmlManagerFor(MapTile.class, City.class);
	}

	@After
	public void cleanUp() {
		outputFile.delete();
	}

	@Test
	public void testThatCityIsLoadedCorrectly() throws Exception {
		MapTile maptile = manager.unmarshall(inputFile);
		City city = (City) maptile.getMapEntities().get(0);
		// setting the parent MapTile
		city.setMapTile(maptile);
		validateInstance(city, new XPathHelper(inputFile));
	}

	@Test
	public void testThatCityIsSavedCorrectly() throws Exception {
		MapTile maptile = manager.unmarshall(inputFile);
		XmlTestHelper.writeObjectToFile(maptile, manager, outputFile);
		City city = (City) maptile.getMapEntities().get(0);
		// setting the parent MapTile
		city.setMapTile(maptile);
		validateInstance(city, new XPathHelper(outputFile));
	}

	private void validateInstance(City city, XPathHelper helper) {

		assertEquals("The position is not set correctly",
				helper.evaluateXPathAsInteger("//mapTile/position/x/text()"),
				city.getPosition().getX());
		assertEquals("The position is not set correctly",
				helper.evaluateXPathAsInteger("//mapTile/position/y/text()"),
				city.getPosition().getY());
		assertEquals("The name is not set correctly",
				helper.evaluateXPathAsString("//city/name/text()"),
				city.getName());
		assertEquals("Player side is not set correctly",
				helper.evaluateXPathAsString("//city/player"),
				city.getPlayer().toString());
		assertEquals("The villages-owned is not set correctly",
				helper.evaluateXPathAsString("//city/villages-owned/text()"),
				city.getListOfOwnedVillages().get(0));
	}

}
