/*
 * Copyright (C) 2011 Paul Statham, Andrea Paternesi, Leonel Iturralde, Ulf Lorenz, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.map.building.village;

import java.io.File;

import org.freelords.map.building.village.Village;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.freelords.xmlmanager.utils.XPathHelper;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.freelords.map.tile.MapTile;

import static junit.framework.Assert.*;

public class VillageJaxbTest {

	private XmlManager manager;
	private File inputFile = new File(this.getClass()
			.getResource("files/village.xml").getFile());
	private File outputFile = new File("test_village.xml");

	@Before
	public void setUp() throws Exception {
		manager = XmlTestHelper.createXmlManagerFor(MapTile.class, Village.class);
	}

	@After
	public void cleanUp() {
		this.outputFile.delete();
	}

	@Test
	public void testThatVillageIsLoadedCorrectly() throws Exception {
		MapTile maptile = manager.unmarshall(this.inputFile);
		Village village = (Village) maptile.getMapEntities().get(0);
		// setting the parent MapTile
		village.setMapTile(maptile);
		validateInstance(village, new XPathHelper(this.inputFile));
	}

	@Test
	public void testThatVillageIsSavedCorrectly() throws Exception {
		MapTile maptile = manager.unmarshall(this.inputFile);
		XmlTestHelper.writeObjectToFile(maptile, manager, this.outputFile);
		Village village = (Village) maptile.getMapEntities().get(0);
		// setting the parent MapTile
		village.setMapTile(maptile);
		validateInstance(village, new XPathHelper(this.outputFile));
	}

	private void validateInstance(Village village, XPathHelper helper) {

		assertEquals("The position is not set correctly",
				helper.evaluateXPathAsInteger("//mapTile/position/x/text()"),
				village.getPosition().getX());
		assertEquals("The position is not set correctly",
				helper.evaluateXPathAsInteger("//mapTile/position/y/text()"),
				village.getPosition().getY());
		assertEquals("The id is not set correctly",
				helper.evaluateXPathAsString("//village/id/text()"),
				village.getId());
		assertEquals("The siege-flag is not set correctly",
				helper.evaluateXPathAsBoolean("//village/siege-flag/text()"),
				village.isUnderSiege());
		assertEquals("The income is not set correctly",
				helper.evaluateXPathAsInteger("//village/income/text()"),
				village.getIncome());
		assertEquals("Player side is not set correctly",
				helper.evaluateXPathAsString("//village/player"),
				village.getPlayer().toString());
	}

}
