/*
 * Copyright (C) 2011 Andrea Paternesi, Premkumar Bhaskal
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.jaxb.player;

import static junit.framework.Assert.assertEquals;

import java.io.File;

import org.freelords.player.Player;
import org.freelords.xmlmanager.utils.XPathHelper;
import org.freelords.xmlmanager.XmlManager;
import org.freelords.xmlmanager.utils.XmlTestHelper;
import org.junit.Before;
import org.junit.Test;

/** Tests serializing and deserializing of an Player instance. */
public class PlayerJaxbTest {

	// to load the data
	private XmlManager xmlManager;
	// files for deserializing and serializing the Player instance
	private File playerFile = new File(this.getClass().getResource("files/player.xml").getFile());
	private File outputFile = new File("player_out.xml");
	// needed for verifications
	private XPathHelper xPathHelper = new XPathHelper(this.playerFile);

	@Before
	public void setUp() throws Exception {
		this.xmlManager = XmlTestHelper.createXmlManagerFor(Player.class);
	}

	/** Load the player from an xml file. */
	@Test
	public void testPlayerIsReadFromAnXml() throws Exception {
		Player player = this.xmlManager.unmarshall(this.playerFile);
		validatePlayerUnmarshall(player, this.xPathHelper);
	}

	/** Write the player to an xml file. */
	@Test
	public void testUnitIsWrittenInAnXml() throws Exception {
		Player player = xmlManager.unmarshall(this.playerFile);
		XmlTestHelper.writeObjectToFile(player, this.xmlManager, this.outputFile);

		// validate
		validatePlayerMarshall(player, new XPathHelper(this.outputFile));

		// clean up
		removeFile(this.outputFile);
	}

	private void validatePlayerUnmarshall(Player player, XPathHelper helper) {
		// base stats
		assertEquals("The Player Title is not set correctly",
				helper.evaluateXPathAsString("//title/text()"),
				player.getTitle());
		assertEquals("The Player Side is not set correctly",
				helper.evaluateXPathAsString("//side/text()"), player.getSide().toString());
	}
	
	private void validatePlayerMarshall(Player player, XPathHelper helper) {
		assertEquals("The Player was not correctly marshalled",
				player.getTitle(),
				helper.evaluateXPathAsString("//title/text()"));
		assertEquals("The Player was not correctly marshalled", player
				.getSide().toString(),
				helper.evaluateXPathAsString("//side/text()"));
	}

	private void removeFile(File file) {
		file.delete();
	}
}
