/*
 * Copyright (C) 2011 Ion Pana
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
package org.freelords.xmlmanager.utils;

import java.io.File;

import org.freelords.xmlmanager.SimpleXml;
import org.freelords.xmlmanager.SimpleXml2;
import org.freelords.xmlmanager.XmlManager;
import org.junit.Test;
import static junit.framework.Assert.*;

/**
 * The name is a real winner, isn't it?!
 */
public class XmlTestHelperTest {
	
	private File xmlFile1 = new File(this.getClass().getResource("../files/simplexml.xml").getFile());
	private File xmlFile2 = new File(this.getClass().getResource("../files/simplexml2.xml").getFile());
	
	/**
	 * Test to see if the XmlManager is properly constructed and 
	 * can unmarshall some instances of the registered types.
	 * 
	 * @throws Exception
	 */
	@Test
	public void testXmlManagerCreation() throws Exception {
		XmlManager manager = XmlTestHelper.createXmlManagerFor(SimpleXml.class, SimpleXml2.class);
		
		SimpleXml simpleXml = manager.unmarshall(xmlFile1);
		//just check to see if it read something
		assertNotNull(simpleXml);
		
		SimpleXml2 simpleXml2 = manager.unmarshall(xmlFile2);
		assertNotNull(simpleXml2);
	}
	
	/**
	 * Tries to initialize an XmlManager without any classes to register. It should fail.
	 */
	@Test(expected = IllegalArgumentException.class)
	public void testXmlManagerCreationWithNoClasses() {
		XmlTestHelper.createXmlManagerFor();
	}
	
	/**
	 * Write some objects to files.
	 */
	@Test
	public void testWriteToFile() {
		File out = new File("xml_test_helper_out.xml");
		
		SimpleXml simpleXml = new SimpleXml();
		simpleXml.setField("kaboom");
		
		XmlTestHelper.writeObjectToFile(simpleXml, XmlTestHelper.createXmlManagerFor(SimpleXml.class), out);
		
		//and validate results
		XPathHelper helper = new XPathHelper(out);
		assertEquals("The SimpleXml instance was not correctly unmarshalled.", 
				simpleXml.getField(), helper.evaluateXPathAsString("//field"));
		
		//and clean.
		out.delete();
	}
	
	/**
	 * If the file is null, an IllegalArgumentException is thrown.
	 */
	@Test(expected = IllegalArgumentException.class)
	public void testWriteToBadFile() {
		XmlTestHelper.writeObjectToFile(new SimpleXml(), XmlTestHelper.createXmlManagerFor(SimpleXml.class), null);
	}
	
}
